@@ -15,13 +15,13 @@ integratelogisticdup <- function(x1, x2, models, beta, lower=0, width, point){
 
     # do some integration
     integrate(logisticdupbyx_fast, lower=lower, upper=width,
-              subdivisions=10, rel.tol=0.01, abs.tol=0.01,
+#              subdivisions=10, rel.tol=0.01, abs.tol=0.01,
               x1=x1, x2=x2, models=models, beta=beta, point=point,
               beta_distance=beta_distance)$value
   }else{
   # Otherwise just go ahead and do the numerical integration
     integrate(logisticdupbyx, lower=lower, upper=width,
-              subdivisions=10, rel.tol=0.01, abs.tol=0.01,
+#              subdivisions=10, rel.tol=0.01, abs.tol=0.01,
               x1=x1, x2=x2, models=models, beta=beta, point=point)$value
   }
 }
