@@ -12,10 +12,11 @@
 survey.region.dht <- function(Nhat.by.sample, samples, width, point){
   #  Compute effort in each region and the area in the covered region
   Effort.by.region <- by(samples$Effort,samples$Region.Label,sum)
-  if(point)
+  if(point){
     CoveredArea <- pi*as.vector(Effort.by.region)*width^2
-  else
-      CoveredArea <- 2*as.vector(Effort.by.region)*width
+  }else{
+    CoveredArea <- 2*as.vector(Effort.by.region)*width
+  }
 
   # Scale up abundance in covered region to the survey region
   # unless no areas given
